==> freecad_0.16+dfsg2.orig.tar.xz: FreeCAD-0.16/src/Mod/Plot/resources/translations/Plot_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fi" sourcelanguage="en">
  <context>
    <name>Plot</name>
    <message>
      <location filename="InitGui.py" line="44"/>
      <source>Plot edition tools</source>
      <translation>Pistekuvioiden muokkaustyökalut</translation>
    </message>
    <message>
      <location filename="InitGui.py" line="47"/>
      <source>Plot</source>
      <translation>Pistekuvio -plot</translation>
    </message>
  </context>
  <context>
    <name>Plot_Axes</name>
    <message>
      <location filename="PlotGui.py" line="62"/>
      <source>Configure axes</source>
      <translation>Määritä akselit</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="65"/>
      <source>Configure the axes parameters</source>
      <translation>Määritä akselit-parametrit</translation>
    </message>
  </context>
  <context>
    <name>Plot_Grid</name>
    <message>
      <location filename="PlotGui.py" line="110"/>
      <source>Show/Hide grid</source>
      <translation>Piilota/näytä ruudukko</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="113"/>
      <source>Show/Hide grid on selected plot</source>
      <translation>Piilota/näytä ruudukko valitulle käyrän tulostukselle</translation>
    </message>
  </context>
  <context>
    <name>Plot_Labels</name>
    <message>
      <location filename="PlotGui.py" line="154"/>
      <source>Set labels</source>
      <translation>Aseta nimet</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="157"/>
      <source>Set title and axes labels</source>
      <translation>Aseta otsikon ja akseleiden nimet</translation>
    </message>
  </context>
  <context>
    <name>Plot_Legend</name>
    <message>
      <location filename="PlotGui.py" line="137"/>
      <source>Show/Hide legend</source>
      <translation>Näytä/Piilota kuvateksti</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="140"/>
      <source>Show/Hide legend on selected plot</source>
      <translation>Näytä/Piilota kuvateksti valitulta käyrän tulostukselta</translation>
    </message>
  </context>
  <context>
    <name>Plot_Positions</name>
    <message>
      <location filename="PlotGui.py" line="171"/>
      <source>Set positions and sizes</source>
      <translation>Määritä asemat ja koot</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="174"/>
      <source>Set labels and legend positions and sizes</source>
      <translation>Määrä nimien sekä kuvatekstien asemat ja koot</translation>
    </message>
  </context>
  <context>
    <name>Plot_SaveFig</name>
    <message>
      <location filename="PlotGui.py" line="45"/>
      <source>Save plot</source>
      <translation>Tallenna käyrän tulostus</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="48"/>
      <source>Save the plot as an image file</source>
      <translation>Tallenna pistekuvio kuvatiedostona</translation>
    </message>
  </context>
  <context>
    <name>Plot_Series</name>
    <message>
      <location filename="PlotGui.py" line="81"/>
      <source>Configure series</source>
      <translation>Määritä sarjan ominaisuudet</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="84"/>
      <source>Configure series drawing style and label</source>
      <translation>Määritä sarjan piirtotyyli ja sarjan nimi</translation>
    </message>
  </context>
  <context>
    <name>plot_axes</name>
    <message>
      <location filename="TaskPanel.py" line="175"/>
      <source>Configure axes</source>
      <translation>Määritä akselit</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="180"/>
      <source>Active axes</source>
      <translation>Aktivoi akseli</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="220"/>
      <source>Apply to all axes</source>
      <translation>Sovella kaikkiin akseleihin</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="225"/>
      <source>Dimensions</source>
      <translation>Mitat</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="230"/>
      <source>X axis position</source>
      <translation>X akselin sijointi</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="235"/>
      <source>Y axis position</source>
      <translation>Y akselin sijointi</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="205"/>
      <source>Scales</source>
      <translation>Asteikot</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="210"/>
      <source>X auto</source>
      <translation>X automaattinen</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="215"/>
      <source>Y auto</source>
      <translation>Y automaattinen</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="240"/>
      <source>Index of the active axes</source>
      <translation>Aktiivisten akselien indeksi</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="245"/>
      <source>Add new axes to the plot</source>
      <translation>Lisää uusi akseli käyrän tulostukseen</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="251"/>
      <source>Remove selected axes</source>
      <translation>Poista valitut akselit</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="257"/>
      <source>Check it to apply transformations to all axes</source>
      <translation>Tarkista pitääkö muunnoksia soveltaa kaikkiin akseleihin</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="263"/>
      <source>Left bound of axes</source>
      <translation>Akselin vasen raja</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="269"/>
      <source>Right bound of axes</source>
      <translation>Akselin oikea raja</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="275"/>
      <source>Bottom bound of axes</source>
      <translation>Akselin alaraja</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="281"/>
      <source>Top bound of axes</source>
      <translation>Akselin yläraja</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="287"/>
      <source>Outward offset of X axis</source>
      <translation>Ulospäin suuntautuva X akselin siirtymä</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="293"/>
      <source>Outward offset of Y axis</source>
      <translation>Ulospäin suuntautuva Y akselin siirtymä</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="299"/>
      <source>X axis scale autoselection</source>
      <translation>X akselin asteikon automaattisovitus</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="305"/>
      <source>Y axis scale autoselection</source>
      <translation>Y akselin asteikon automaattisovitus</translation>
    </message>
  </context>
  <context>
    <name>plot_console</name>
    <message>
      <location filename="Plot.py" line="43"/>
      <source>matplotlib not found, so Plot module can not be loaded</source>
      <translation>matplotlib Python pakettia ei löydy joten käyrien tulostusmoduulia ei voi ladata</translation>
    </message>
    <message>
      <location filename="InitGui.py" line="54"/>
      <source>matplotlib not found, Plot module will be disabled</source>
      <translation>matplotlib Python pakettia ei löydy joten käyrien tulostusmoduuli poistetaan käytöstä</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="42"/>
      <source>Plot document must be selected in order to save it</source>
      <translation>Käyräntulostusasiakirja pitää valita jotta sen voi tallentaa</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="365"/>
      <source>Axes 0 can not be deleted</source>
      <translation>Akselia 0 ei voi poistaa</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="97"/>
      <source>The grid must be activated on top of a plot document</source>
      <translation>Ruudukko täytyy aktivoida pistekuvioasiakirjan päällä</translation>
    </message>
    <message>
      <location filename="PlotGui.py" line="126"/>
      <source>The legend must be activated on top of a plot document</source>
      <translation>Selitykset täytyy aktivoida pistekuvioasiakirjan päälle</translation>
    </message>
  </context>
  <context>
    <name>plot_labels</name>
    <message>
      <location filename="TaskPanel.py" line="133"/>
      <source>Set labels</source>
      <translation>Aseta nimet</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="138"/>
      <source>Active axes</source>
      <translation>Aktivoi akseli</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="143"/>
      <source>Title</source>
      <translation>Otsikko</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="148"/>
      <source>X label</source>
      <translation>X akselin nimi</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="153"/>
      <source>Y label</source>
      <translation>Y akselin nimi</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="158"/>
      <source>Index of the active axes</source>
      <translation>Aktiivisten akselien indeksi</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="163"/>
      <source>Title (associated to active axes)</source>
      <translation>Otsikko (aktiivisen akselin)</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="169"/>
      <source>Title font size</source>
      <translation>Otsikon fontin koko</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="175"/>
      <source>X axis title</source>
      <translation>X akselin otsikko</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="181"/>
      <source>X axis title font size</source>
      <translation>X akselin otsikon fontin koko</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="187"/>
      <source>Y axis title</source>
      <translation>Y akselin otsikko</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="193"/>
      <source>Y axis title font size</source>
      <translation>Y akselin otsikon fontin koko</translation>
    </message>
  </context>
  <context>
    <name>plot_positions</name>
    <message>
      <location filename="TaskPanel.py" line="121"/>
      <source>Set positions and sizes</source>
      <translation>Määritä asemat ja koot</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="126"/>
      <source>Position</source>
      <translation>Sijainti</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="132"/>
      <source>Size</source>
      <translation>Koko</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="138"/>
      <source>List of modificable items</source>
      <translation>Muokattavien kohteiden luettelo</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="144"/>
      <source>X item position</source>
      <translation>Kohteen X suuntainen sijainti</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="150"/>
      <source>Y item position</source>
      <translation>Kohteen Y suuntainen sijainti</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="156"/>
      <source>Item size</source>
      <translation>Kohteen koko</translation>
    </message>
  </context>
  <context>
    <name>plot_save</name>
    <message>
      <location filename="TaskPanel.py" line="128"/>
      <source>Save figure</source>
      <translation>Tallenna kuva</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="133"/>
      <source>Inches</source>
      <translation>Tuumaa</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="139"/>
      <source>Dots per Inch</source>
      <translation>Pistettä tuumalla</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="145"/>
      <source>Output image file path</source>
      <translation>Tulosteena tuleen kuvan tiedostopolku</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="151"/>
      <source>Show a file selection dialog</source>
      <translation>Näytä tiedostovalintaikkuna</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="157"/>
      <source>X image size</source>
      <translation>X suuntainen kuvan koko</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="163"/>
      <source>Y image size</source>
      <translation>Y suuntainen kuvan koko</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="169"/>
      <source>Dots per point, with size will define output image resolution</source>
      <translation>Pistettä per kohta, leveys määrittää kuvan</translation>
    </message>
  </context>
  <context>
    <name>plot_series</name>
    <message>
      <location filename="TaskPanel.py" line="154"/>
      <source>No label</source>
      <translation>Ei selitettä</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="160"/>
      <source>Remove serie</source>
      <translation>Poista sarja</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="196"/>
      <source>Line style</source>
      <translation>Viivatyyli</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="172"/>
      <source>Marker</source>
      <translation>Merkki</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="149"/>
      <source>Configure series</source>
      <translation>Määritä sarjan ominaisuudet</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="178"/>
      <source>List of available series</source>
      <translation>Käytettävissä olevien sarjojen luettelo</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="184"/>
      <source>Line title</source>
      <translation>Viivan otsikko</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="202"/>
      <source>Marker style</source>
      <translation>Merkin tyyli</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="208"/>
      <source>Line width</source>
      <translation>Viivan leveys</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="214"/>
      <source>Marker size</source>
      <translation>Merkin koko</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="220"/>
      <source>Line and marker color</source>
      <translation>Viivan ja merkin väri</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="226"/>
      <source>Removes this serie</source>
      <translation>Poistaa tämän sarjan</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="190"/>
      <source>If checked serie will not be considered for legend</source>
      <translation>Jos valittuna sarjaa ei oteta huomioon määritettäessä otsikkoa</translation>
    </message>
  </context>
</TS>

==> freecad_0.18.4+dfsg2.orig.tar.xz: FreeCAD-0.18.4/src/Mod/Plot/resources/translations/Plot_fi.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fi" sourcelanguage="en">
  <context>
    <name>Plot</name>
    <message>
      <location filename="../../InitGui.py" line="44"/>
      <source>Plot edition tools</source>
      <translation>Pistekuvioiden muokkaustyökalut</translation>
    </message>
    <message>
      <location filename="../../InitGui.py" line="47"/>
      <source>Plot</source>
      <translation>Pistekuvio -plot</translation>
    </message>
  </context>
  <context>
    <name>Plot_Axes</name>
    <message>
      <location filename="../../PlotGui.py" line="62"/>
      <source>Configure axes</source>
      <translation>Määritä akselit</translation>
    </message>
    <message>
      <location filename="../../PlotGui.py" line="65"/>
      <source>Configure the axes parameters</source>
      <translation>Määritä akselit-parametrit</translation>
    </message>
  </context>
  <context>
    <name>Plot_Grid</name>
    <message>
      <location filename="../../PlotGui.py" line="109"/>
      <source>Show/Hide grid</source>
      <translation>Piilota/näytä ruudukko</translation>
    </message>
    <message>
      <location filename="../../PlotGui.py" line="112"/>
      <source>Show/Hide grid on selected plot</source>
      <translation>Piilota/näytä ruudukko valitulle käyrän tulostukselle</translation>
    </message>
  </context>
  <context>
    <name>Plot_Labels</name>
    <message>
      <location filename="../../PlotGui.py" line="152"/>
      <source>Set labels</source>
      <translation>Aseta nimet</translation>
    </message>
    <message>
      <location filename="../../PlotGui.py" line="155"/>
      <source>Set title and axes labels</source>
      <translation>Aseta otsikon ja akseleiden nimet</translation>
    </message>
  </context>
  <context>
    <name>Plot_Legend</name>
    <message>
      <location filename="../../PlotGui.py" line="135"/>
      <source>Show/Hide legend</source>
      <translation>Näytä/Piilota kuvateksti</translation>
    </message>
    <message>
      <location filename="../../PlotGui.py" line="138"/>
      <source>Show/Hide legend on selected plot</source>
      <translation>Näytä/Piilota kuvateksti valitulta käyrän tulostukselta</translation>
    </message>
  </context>
  <context>
    <name>Plot_Positions</name>
    <message>
      <location filename="../../PlotGui.py" line="169"/>
      <source>Set positions and sizes</source>
      <translation>Määritä asemat ja koot</translation>
    </message>
    <message>
      <location filename="../../PlotGui.py" line="172"/>
      <source>Set labels and legend positions and sizes</source>
      <translation>Määrä nimien sekä kuvatekstien asemat ja koot</translation>
    </message>
  </context>
  <context>
    <name>Plot_SaveFig</name>
    <message>
      <location filename="../../PlotGui.py" line="45"/>
      <source>Save plot</source>
      <translation>Tallenna käyrän tulostus</translation>
    </message>
    <message>
      <location filename="../../PlotGui.py" line="48"/>
      <source>Save the plot as an image file</source>
      <translation>Tallenna pistekuvio kuvatiedostona</translation>
    </message>
  </context>
  <context>
    <name>Plot_Series</name>
    <message>
      <location filename="../../PlotGui.py" line="81"/>
      <source>Configure series</source>
      <translation>Määritä sarjan ominaisuudet</translation>
    </message>
    <message>
      <location filename="../../PlotGui.py" line="84"/>
      <source>Configure series drawing style and label</source>
      <translation>Määritä sarjan piirtotyyli ja sarjan nimi</translation>
    </message>
  </context>
  <context>
    <name>plot_axes</name>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="175"/>
      <source>Configure axes</source>
      <translation>Määritä akselit</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="179"/>
      <source>Active axes</source>
      <translation>Aktivoi akseli</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="211"/>
      <source>Apply to all axes</source>
      <translation>Sovella kaikkiin akseleihin</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="215"/>
      <source>Dimensions</source>
      <translation>Mitat</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="219"/>
      <source>X axis position</source>
      <translation>X akselin sijointi</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="223"/>
      <source>Y axis position</source>
      <translation>Y akselin sijointi</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="199"/>
      <source>Scales</source>
      <translation>Asteikot</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="203"/>
      <source>X auto</source>
      <translation>X automaattinen</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="207"/>
      <source>Y auto</source>
      <translation>Y automaattinen</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="227"/>
      <source>Index of the active axes</source>
      <translation>Aktiivisten akselien indeksi</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="231"/>
      <source>Add new axes to the plot</source>
      <translation>Lisää uusi akseli käyrän tulostukseen</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="236"/>
      <source>Remove selected axes</source>
      <translation>Poista valitut akselit</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="241"/>
      <source>Check it to apply transformations to all axes</source>
      <translation>Tarkista pitääkö muunnoksia soveltaa kaikkiin akseleihin</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="246"/>
      <source>Left bound of axes</source>
      <translation>Akselin vasen raja</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="251"/>
      <source>Right bound of axes</source>
      <translation>Akselin oikea raja</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="256"/>
      <source>Bottom bound of axes</source>
      <translation>Akselin alaraja</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="261"/>
      <source>Top bound of axes</source>
      <translation>Akselin yläraja</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="266"/>
      <source>Outward offset of X axis</source>
      <translation>Ulospäin suuntautuva X akselin siirtymä</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="271"/>
      <source>Outward offset of Y axis</source>
      <translation>Ulospäin suuntautuva Y akselin siirtymä</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="276"/>
      <source>X axis scale autoselection</source>
      <translation>X akselin asteikon automaattisovitus</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="281"/>
      <source>Y axis scale autoselection</source>
      <translation>Y akselin asteikon automaattisovitus</translation>
    </message>
  </context>
  <context>
    <name>plot_console</name>
    <message>
      <location filename="../../Plot.py" line="43"/>
      <source>matplotlib not found, so Plot module can not be loaded</source>
      <translation>matplotlib Python pakettia ei löydy joten käyrien tulostusmoduulia ei voi ladata</translation>
    </message>
    <message>
      <location filename="../../InitGui.py" line="54"/>
      <source>matplotlib not found, Plot module will be disabled</source>
      <translation>matplotlib Python pakettia ei löydy joten käyrien tulostusmoduuli poistetaan käytöstä</translation>
    </message>
    <message>
      <location filename="../../plotSave/TaskPanel.py" line="42"/>
      <source>Plot document must be selected in order to save it</source>
      <translation>Käyräntulostusasiakirja pitää valita jotta sen voi tallentaa</translation>
    </message>
    <message>
      <location filename="../../plotAxes/TaskPanel.py" line="340"/>
      <source>Axes 0 can not be deleted</source>
      <translation>Akselia 0 ei voi poistaa</translation>
    </message>
    <message>
      <location filename="../../PlotGui.py" line="97"/>
      <source>The grid must be activated on top of a plot document</source>
      <translation>Ruudukko täytyy aktivoida pistekuvioasiakirjan päällä</translation>
    </message>
    <message>
      <location filename="../../PlotGui.py" line="125"/>
      <source>The legend must be activated on top of a plot document</source>
      <translation>Selitykset täytyy aktivoida pistekuvioasiakirjan päälle</translation>
    </message>
  </context>
  <context>
    <name>plot_labels</name>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="133"/>
      <source>Set labels</source>
      <translation>Aseta nimet</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="137"/>
      <source>Active axes</source>
      <translation>Aktivoi akseli</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="141"/>
      <source>Title</source>
      <translation>Otsikko</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="145"/>
      <source>X label</source>
      <translation>X akselin nimi</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="149"/>
      <source>Y label</source>
      <translation>Y akselin nimi</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="153"/>
      <source>Index of the active axes</source>
      <translation>Aktiivisten akselien indeksi</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="157"/>
      <source>Title (associated to active axes)</source>
      <translation>Otsikko (aktiivisen akselin)</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="162"/>
      <source>Title font size</source>
      <translation>Otsikon fontin koko</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="167"/>
      <source>X axis title</source>
      <translation>X akselin otsikko</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="172"/>
      <source>X axis title font size</source>
      <translation>X akselin otsikon fontin koko</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="177"/>
      <source>Y axis title</source>
      <translation>Y akselin otsikko</translation>
    </message>
    <message>
      <location filename="../../plotLabels/TaskPanel.py" line="182"/>
      <source>Y axis title font size</source>
      <translation>Y akselin otsikon fontin koko</translation>
    </message>
  </context>
  <context>
    <name>plot_positions</name>
    <message>
      <location filename="../../plotPositions/TaskPanel.py" line="121"/>
      <source>Set positions and sizes</source>
      <translation>Määritä asemat ja koot</translation>
    </message>
    <message>
      <location filename="../../plotPositions/TaskPanel.py" line="125"/>
      <source>Position</source>
      <translation>Sijainti</translation>
    </message>
    <message>
      <location filename="../../plotPositions/TaskPanel.py" line="130"/>
      <source>Size</source>
      <translation>Koko</translation>
    </message>
    <message>
      <location filename="../../plotPositions/TaskPanel.py" line="140"/>
      <source>X item position</source>
      <translation>Kohteen X suuntainen sijainti</translation>
    </message>
    <message>
      <location filename="../../plotPositions/TaskPanel.py" line="145"/>
      <source>Y item position</source>
      <translation>Kohteen Y suuntainen sijainti</translation>
    </message>
    <message>
      <location filename="../../plotPositions/TaskPanel.py" line="150"/>
      <source>Item size</source>
      <translation>Kohteen koko</translation>
    </message>
    <message>
      <location filename="../../plotPositions/TaskPanel.py" line="135"/>
      <source>List of modifiable items</source>
      <translation>Muokattavien kohteiden luettelo</translation>
    </message>
  </context>
  <context>
    <name>plot_save</name>
    <message>
      <location filename="../../plotSave/TaskPanel.py" line="127"/>
      <source>Save figure</source>
      <translation>Tallenna kuva</translation>
    </message>
    <message>
      <location filename="../../plotSave/TaskPanel.py" line="131"/>
      <source>Inches</source>
      <translation>Tuumaa</translation>
    </message>
    <message>
      <location filename="../../plotSave/TaskPanel.py" line="136"/>
      <source>Dots per Inch</source>
      <translation>Pistettä tuumalla</translation>
    </message>
    <message>
      <location filename="../../plotSave/TaskPanel.py" line="141"/>
      <source>Output image file path</source>
      <translation>Tulosteena tuleen kuvan tiedostopolku</translation>
    </message>
    <message>
      <location filename="../../plotSave/TaskPanel.py" line="146"/>
      <source>Show a file selection dialog</source>
      <translation>Näytä tiedostovalintaikkuna</translation>
    </message>
    <message>
      <location filename="../../plotSave/TaskPanel.py" line="151"/>
      <source>X image size</source>
      <translation>X suuntainen kuvan koko</translation>
    </message>
    <message>
      <location filename="../../plotSave/TaskPanel.py" line="156"/>
      <source>Y image size</source>
      <translation>Y suuntainen kuvan koko</translation>
    </message>
    <message>
      <location filename="../../plotSave/TaskPanel.py" line="161"/>
      <source>Dots per point, with size will define output image resolution</source>
      <translation>Pistettä per kohta, leveys määrittää kuvan</translation>
    </message>
  </context>
  <context>
    <name>plot_series</name>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="153"/>
      <source>No label</source>
      <translation>Ei selitettä</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="188"/>
      <source>Line style</source>
      <translation>Viivatyyli</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="168"/>
      <source>Marker</source>
      <translation>Merkki</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="149"/>
      <source>Configure series</source>
      <translation>Määritä sarjan ominaisuudet</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="173"/>
      <source>List of available series</source>
      <translation>Käytettävissä olevien sarjojen luettelo</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="178"/>
      <source>Line title</source>
      <translation>Viivan otsikko</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="193"/>
      <source>Marker style</source>
      <translation>Merkin tyyli</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="198"/>
      <source>Line width</source>
      <translation>Viivan leveys</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="203"/>
      <source>Marker size</source>
      <translation>Merkin koko</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="208"/>
      <source>Line and marker color</source>
      <translation>Viivan ja merkin väri</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="158"/>
      <source>Remove series</source>
      <translation>Poista sarja</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="183"/>
      <source>If checked, series will not be considered for legend</source>
      <translation>Poista sarjan selite</translation>
    </message>
    <message>
      <location filename="../../plotSeries/TaskPanel.py" line="213"/>
      <source>Removes this series</source>
      <translation>Poistaa tämän sarjan</translation>
    </message>
  </context>
</TS>
